@@ -1,5 +1,5 @@
 #!/usr/bin/python -OO
-# Copyright 2008-2009 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2011 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -25,43 +25,34 @@ from Cheetah.Template import Template
 
 import sabnzbd
 from sabnzbd.constants import *
-from sabnzbd.lang import T, list_languages, reset_language
+import sabnzbd.api
+from sabnzbd.lang import list_languages, set_language
 from sabnzbd.utils.servertests import test_nntp_server_dict
+from sabnzbd.api import Ttemplate
 import sabnzbd.interface
 import sabnzbd.config as config
 import sabnzbd.cfg as cfg
 
-################################################################################
-# Table to map 0.5.x style language code to new style
-LANG_MAP = {
-    'de-de' : 'de',
-    'dk-da' : 'da', # Should have been "da-dk"
-    'fr-fr' : 'fr',
-    'nl-du' : 'nl', # Should have been "du-nl"
-    'no-no' : 'nb', # Norsk Bokmal
-    'sv-se' : 'sv',
-    'us-en' : 'en'  # Should have been "en-us"
-}
-
 #------------------------------------------------------------------------------
-class Wizard:
+class Wizard(object):
     def __init__(self, web_dir, root, prim):
         self.__root = root
         # Get the path for the folder named wizard
         self.__web_dir = sabnzbd.WIZARD_DIR
         self.__prim = prim
         self.info = {'webdir': sabnzbd.WIZARD_DIR,
-                     'steps':5, 'version':sabnzbd.__version__,
+                     'steps':4, 'version':sabnzbd.__version__,
                      'T': T}
 
     @cherrypy.expose
     def index(self, **kwargs):
-
+        """ Show the language selection page """
         info = self.info.copy()
         info['num'] = ''
         info['number'] = 0
-        info['lang'] = cfg.LANGUAGE.get()
-        info['languages'] = list_languages(sabnzbd.DIR_LANGUAGE)
+        info['lang'] = cfg.language()
+        info['languages'] = list_languages()
+        info['T'] = Ttemplate
 
         if not os.path.exists(self.__web_dir):
             # If the wizard folder does not exist, simply load the normal page
@@ -71,73 +62,33 @@ class Wizard:
                                 searchList=[info], compilerSettings=sabnzbd.interface.DIRECTIVES)
             return template.respond()
 
+    @cherrypy.expose
+    def exit(self, **kwargs):
+        """ Stop SABnzbd """
+        yield "Initiating shutdown..."
+        sabnzbd.halt()
+        yield "<br>SABnzbd-%s shutdown finished" % sabnzbd.__version__
+        cherrypy.engine.exit()
+        sabnzbd.SABSTOP = True
+
     @cherrypy.expose
     def one(self, **kwargs):
-        # Handle special options
+        """ Accept language and show server page """
         language = kwargs.get('lang')
-        if language and language != cfg.LANGUAGE.get():
-            cfg.LANGUAGE.set(language)
-            reset_language(language)
+        cfg.language.set(language)
+        set_language(language)
+        sabnzbd.api.cache_skin_trans()
+
+        # Always setup Plush
+        sabnzbd.interface.change_web_dir('Plush - Gold')
 
         info = self.info.copy()
-        info['num'] = '&raquo; %s' % T('wizard-step-one')
+        info['num'] = '&raquo; %s' % T('Step One')
         info['number'] = 1
-        info['skin'] = cfg.WEB_DIR.get().lower()
-
-        template = Template(file=os.path.join(self.__web_dir, 'one.html'),
-                                searchList=[info], compilerSettings=sabnzbd.interface.DIRECTIVES)
-        return template.respond()
-
-    @cherrypy.expose
-    def two(self, **kwargs):
-        # Save skin setting
-        if kwargs:
-            if 'skin' in kwargs:
-                sabnzbd.interface.change_web_dir(kwargs['skin'])
-
-        info = self.info.copy()
-        info['num'] = '&raquo; %s' % T('wizard-step-two')
-        info['number'] = 2
-
-        host = cfg.CHERRYHOST.get()
-        info['host'] = host
-        # Allow special operation if host is not one of the defaults
-        if host not in ('localhost','0.0.0.0'):
-            info['custom_host'] = True
-        else:
-            info['custom_host'] = False
-
-        if sabnzbd.newswrapper.HAVE_SSL:
-            info['have_ssl'] = True
-        else:
-            info['have_ssl'] = False
-
-        info['enable_https'] = cfg.ENABLE_HTTPS.get()
-        info['autobrowser'] = cfg.AUTOBROWSER.get()
-        info['web_user'] = cfg.USERNAME.get()
-        info['web_pass'] = cfg.PASSWORD.get()
-
-        template = Template(file=os.path.join(self.__web_dir, 'two.html'),
-                            searchList=[info], compilerSettings=sabnzbd.interface.DIRECTIVES)
-        return template.respond()
-
-    @cherrypy.expose
-    def three(self, **kwargs):
-        # Save access/autobrowser/autostart
-        if kwargs:
-            if 'access' in kwargs:
-                cfg.CHERRYHOST.set(kwargs['access'])
-            cfg.ENABLE_HTTPS.set(kwargs.get('enable_https',0))
-            cfg.AUTOBROWSER.set(kwargs.get('autobrowser',0))
-            cfg.USERNAME.set(kwargs.get('web_user', ''))
-            cfg.PASSWORD.set(kwargs.get('web_pass', ''))
-            if not cfg.USERNAME.get() or not cfg.PASSWORD.get():
-                sabnzbd.interface.set_auth(cherrypy.config)
-        info = self.info.copy()
-        info['num'] = '&raquo; %s' % T('wizard-step-three')
-        info['number'] = 3
-        info['session'] = cfg.API_KEY.get()
-        info['language'] = LANG_MAP.get(cfg.LANGUAGE.get(), 'en')
+        info['session'] = cfg.api_key()
+        info['language'] = cfg.language()
+        info['T'] = Ttemplate
+        info['have_ssl'] = bool(sabnzbd.newswrapper.HAVE_SSL)
 
         servers = config.get_servers()
         if not servers:
@@ -151,60 +102,105 @@ class Wizard:
             for server in servers:
                 # If there are multiple servers, just use the first enabled one
                 s = servers[server]
-                info['host'] = s.host.get()
-                info['port'] = s.port.get()
-                info['username'] = s.username.get()
+                info['host'] = s.host()
+                info['port'] = s.port()
+                info['username'] = s.username()
                 info['password'] = s.password.get_stars()
-                info['connections'] = s.connections.get()
-                info['ssl'] = s.ssl.get()
-                if s.enable.get():
+                info['connections'] = s.connections()
+
+                info['ssl'] = s.ssl()
+                if s.enable():
                     break
+        template = Template(file=os.path.join(self.__web_dir, 'one.html'),
+                            searchList=[info], compilerSettings=sabnzbd.interface.DIRECTIVES)
+        return template.respond()
+
+
+    @cherrypy.expose
+    def two(self, **kwargs):
+        """ Accept server and show internal web server page """
+        # Save server details
+        if kwargs:
+            kwargs['enable'] = 1
+            sabnzbd.interface.handle_server(kwargs)
+
+        # Create web server page
+        info = self.info.copy()
+        info['num'] = '&raquo; %s' % T('Step Two')
+        info['number'] = 2
+        info['T'] = Ttemplate
+
+        host = cfg.cherryhost()
+        info['host'] = host
+        # Allow special operation if host is not one of the defaults
+        if host not in ('localhost','0.0.0.0'):
+            info['custom_host'] = True
+        else:
+            info['custom_host'] = False
+
+        info['have_ssl'] = bool(sabnzbd.newswrapper.HAVE_SSL)
+        info['enable_https'] = cfg.enable_https()
+        info['autobrowser'] = cfg.autobrowser()
+        info['web_user'] = cfg.username()
+        info['web_pass'] = cfg.password()
+
+        template = Template(file=os.path.join(self.__web_dir, 'two.html'),
+                            searchList=[info], compilerSettings=sabnzbd.interface.DIRECTIVES)
+        return template.respond()
+
+
+    @cherrypy.expose
+    def three(self, **kwargs):
+        """ Accept webserver parms and show Indexers page """
+        if kwargs:
+            if 'access' in kwargs:
+                cfg.cherryhost.set(kwargs['access'])
+            cfg.enable_https.set(kwargs.get('enable_https',0))
+            cfg.autobrowser.set(kwargs.get('autobrowser',0))
+            cfg.username.set(kwargs.get('web_user', ''))
+            cfg.password.set(kwargs.get('web_pass', ''))
+            if not cfg.username() or not cfg.password():
+                sabnzbd.interface.set_auth(cherrypy.config)
+
+        # Create Indexers page
+        info = self.info.copy()
+        info['num'] = '&raquo; %s' % T('Step Three')
+        info['number'] = 3
+        info['newzbin_user'] = cfg.newzbin_username()
+        info['newzbin_pass'] = cfg.newzbin_password.get_stars()
+        info['newzbin_bookmarks'] = cfg.newzbin_bookmarks()
+        info['matrix_user'] = cfg.matrix_username()
+        info['matrix_apikey'] = cfg.matrix_apikey()
+        info['T'] = Ttemplate
         template = Template(file=os.path.join(self.__web_dir, 'three.html'),
                             searchList=[info], compilerSettings=sabnzbd.interface.DIRECTIVES)
         return template.respond()
 
     @cherrypy.expose
     def four(self, **kwargs):
-        # Save server details
-        if kwargs:
-            kwargs['enable'] = 1
-            sabnzbd.interface.handle_server(kwargs)
-
-        info = self.info.copy()
-        info['num'] = '&raquo; %s' % T('wizard-step-four')
-        info['number'] = 4
-        info['newzbin_user'] = cfg.USERNAME_NEWZBIN.get()
-        info['newzbin_pass'] = cfg.PASSWORD_NEWZBIN.get_stars()
-        info['newzbin_bookmarks'] = cfg.NEWZBIN_BOOKMARKS.get()
-        info['matrix_user'] = cfg.MATRIX_USERNAME.get()
-        info['matrix_apikey'] = cfg.MATRIX_APIKEY.get()
-        template = Template(file=os.path.join(self.__web_dir, 'four.html'),
-                            searchList=[info], compilerSettings=sabnzbd.interface.DIRECTIVES)
-        return template.respond()
-
-    @cherrypy.expose
-    def five(self, **kwargs):
-        # Save server details
+        """ Accept Indexers and show Restart screen """
         if kwargs:
             if 'newzbin_user' in kwargs and 'newzbin_pass' in kwargs:
-                cfg.USERNAME_NEWZBIN.set(kwargs.get('newzbin_user',''))
-                cfg.PASSWORD_NEWZBIN.set(kwargs.get('newzbin_pass',''))
-            cfg.NEWZBIN_BOOKMARKS.set(kwargs.get('newzbin_bookmarks', '0'))
+                cfg.newzbin_username.set(kwargs.get('newzbin_user',''))
+                cfg.newzbin_password.set(kwargs.get('newzbin_pass',''))
+            cfg.newzbin_bookmarks.set(kwargs.get('newzbin_bookmarks', '0'))
             if 'matrix_user' in kwargs and 'matrix_apikey' in kwargs:
-                cfg.MATRIX_USERNAME.set(kwargs.get('matrix_user',''))
-                cfg.MATRIX_APIKEY.set(kwargs.get('matrix_apikey',''))
+                cfg.matrix_username.set(kwargs.get('matrix_user',''))
+                cfg.matrix_apikey.set(kwargs.get('matrix_apikey',''))
 
         config.save_config()
 
+        # Show Restart screen
         info = self.info.copy()
-        info['num'] = '&raquo; %s' % T('wizard-step-five')
-        info['number'] = 5
+        info['num'] = '&raquo; %s' % T('Step Four')
+        info['number'] = 4
         info['helpuri'] = 'http://wiki.sabnzbd.org/'
-        info['session'] = cfg.API_KEY.get()
+        info['session'] = cfg.api_key()
 
         info['access_url'], info['urls'] = self.get_access_info()
+        info['T'] = Ttemplate
 
-        template = Template(file=os.path.join(self.__web_dir, 'five.html'),
+        template = Template(file=os.path.join(self.__web_dir, 'four.html'),
                             searchList=[info], compilerSettings=sabnzbd.interface.DIRECTIVES)
         return template.respond()
 
@@ -212,7 +208,7 @@ class Wizard:
         ''' Build up a list of url's that sabnzbd can be accessed from '''
         # Access_url is used to provide the user a link to sabnzbd depending on the host
         access_uri = 'localhost'
-        cherryhost = cfg.CHERRYHOST.get()
+        cherryhost = cfg.cherryhost()
 
         if cherryhost == '0.0.0.0':
             import socket
@@ -265,17 +261,17 @@ class Wizard:
         urls = []
         for sock in socks:
             if sock:
-                if cfg.ENABLE_HTTPS.get():
-                    url = 'https://%s:%s/sabnzbd/' % (sock, cfg.HTTPS_PORT.get())
+                if cfg.enable_https():
+                    url = 'https://%s:%s/sabnzbd/' % (sock, cfg.https_port())
                 else:
-                    url = 'http://%s:%s/sabnzbd/' % (sock, cfg.CHERRYPORT.get())
+                    url = 'http://%s:%s/sabnzbd/' % (sock, cfg.cherryport())
 
                 urls.append(url)
 
-        if cfg.ENABLE_HTTPS.get():
-            access_url = 'https://%s:%s/sabnzbd/' % (access_uri, cfg.HTTPS_PORT.get())
+        if cfg.enable_https():
+            access_url = 'https://%s:%s/sabnzbd/' % (access_uri, cfg.https_port())
         else:
-            access_url = 'http://%s:%s/sabnzbd/' % (access_uri, cfg.CHERRYPORT.get())
+            access_url = 'http://%s:%s/sabnzbd/' % (access_uri, cfg.cherryport())
 
         return access_url, urls
 
